# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, TypedDict

__all__ = ["OrgUpdateParams"]


class OrgUpdateParams(TypedDict, total=False):
    billing_tier: str
    """Updated billing tier."""

    name: Optional[str]
    """Updated name."""

    status: Optional[Literal["active", "suspended", "deleted"]]
    """Updated status."""
