# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["OrgCreateParams"]


class OrgCreateParams(TypedDict, total=False):
    name: Required[str]
    """Human-readable name for the organization."""

    billing_tier: Optional[str]
    """Optional billing tier identifier."""
